/*
 * Project name:
     HID Read Write Interrupt (USB HID Read & Write Test)
 * Copyright:
     (c) MikroElektronika, 2005-2010
 * Revision History:
     20100512:
       - initial release;
 * Description:
     This example establishes connection with the HID terminal that is active
     on the PC. Upon connection establishment, the HID Device Name will appear
     in the respective window. The character that user sends to PIC from the HID
     terminal will be re-sent back to user.
 * Test configuration:
     MCU:             PIC18F4550
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39632D.pdf
     Dev.Board:       EasyPIC7
                      http://www.mikroe.com/easypic/
     Oscillator:      HS 8.000 MHz  (USB osc. is raised with PLL to 48.000MHz)
     Ext. Modules:    on-board USB-HID
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/mikroc/pic/
 * NOTES:
     (*) Be VERY careful about the configuration flags for the 18F4550 - there's
     so much place for mistake!
    - Place jumpers J12 in the right position
*/
#define on 0x05
#define off 0x04
unsigned char readbuff[64] absolute 0x500;   // Buffers should be in USB RAM, please consult datasheet
unsigned char writebuff[64] absolute 0x540;
 unsigned int temp_res;
 unsigned int temp_res1;
 int i;
char uart_rd,output[35];
char cnt;
char kk;
long sum;
void txpacket(int value);
void onoff(int value);

void interrupt(){

   USB_Interrupt_Proc();                   // USB servicing is done inside the interrupt
}

void main(void){

  TRISA  = 0xFF;              // PORTA is input
  ADCON1 |= 0x00;                         // Configure all ports with analog function as digital
  CMCON  |= 7;                            // Disable comparators
  TRISB = 0;
  LATB = 0;
  UART1_Init(9600);               // Initialize UART module at 9600 bps
  Delay_ms(100);                  // Wait for UART module to stabilize
  HID_Enable(&readbuff,&writebuff);       // Enable HID communication

  while(1){
     UART1_Read_Text(output, "~", 35);
     

    while(!HID_Read());
    txpacket(readbuff[1]);
    UART1_Read_Text(output, "~", 35);
    switch(readbuff[0]){
         case 0x79:
          txpacket(readbuff[1]);
         onoff(0x04);
         
         break;
         case 0x80:
          txpacket(readbuff[1]);
          onoff(0x05);
          
          break;
         /*case 0x81:
         //PORTB=~PORTB;
         writebuff[0]=0x81;
         writebuff[1]=0x00;
         while(!HID_Write(&writebuff,64));*/
         
         case 0x82:
         UART1_Read_Text(output, "~", 35);

         for(i=0;i<35;i++)
         {
         writebuff[i]=output[i];
          }
         txpacket(readbuff[1]);
         while(!HID_Write(&writebuff,64));
         break;
          }
         
         }


  }
  
  void txpacket(int value){
  UART1_Write(0x7e);
 UART1_Write(0x00);
 UART1_Write(0x0f);
 UART1_Write(0x10);
 UART1_Write(0x00);
 UART1_Write(0x00);
 UART1_Write(0x13);
 UART1_Write(0xa2);
 UART1_Write(0x00);
 UART1_Write(0x40);
 UART1_Write(0xb0);
 UART1_Write(0xa2);
 UART1_Write(0x4e);
 UART1_Write(0xff);
 UART1_Write(0xfc);
 UART1_Write(0x00);
 UART1_Write(0x00);
 UART1_Write(value);
 sum =0xff-((0x10 + 0x00 + 0x13 + 0xa2 + 0x40 + 0xb0 + 0xa2 + 0x4e + 0xff+0xfc+value)&0xff);
 UART1_Write(sum);
 Delay_ms(10);
   }
   
 void onoff(int value){
 UART1_Write(0x7e);
 UART1_Write(0x00);
 UART1_Write(0x10);
 UART1_Write(0x17);
 UART1_Write(0x00);
 UART1_Write(0x00);
 UART1_Write(0x13);
 UART1_Write(0xa2);
 UART1_Write(0x00);
 UART1_Write(0x40);
 UART1_Write(0xb0);
 UART1_Write(0xa2);
 UART1_Write(0x4e);
 UART1_Write(0xff);
 UART1_Write(0xfc);
 UART1_Write(0x02);
 UART1_Write(0x44);
 UART1_Write(0x34);
 UART1_Write(value);
 sum =0xff-((0x17 + 0x00 + 0x13 + 0xa2 + 0x40 + 0xb0 + 0xa2 + 0x4e + 0xff+0xfc+0x02+0x44+0x34+value)&0xff);
 UART1_Write(sum);
 
 }